@@ -1108,7 +1108,7 @@ sub draw_toolbar_input_select {
 	}
 	
 	$html .= <<EOH;
-		<select name="$$options{name}" onChange="submit()" onkeypress="typeAhead()" style="visibility:expression(last_vert_menu [0] || subsets_are_visible ? 'hidden' : '')">
+		<select name="$$options{name}" onChange="$$options{onChange}" onkeypress="typeAhead()" style="visibility:expression(last_vert_menu [0] || subsets_are_visible ? 'hidden' : '')">
 EOH
 
 	if (defined $options -> {empty}) {
@@ -1833,14 +1833,15 @@ sub draw_page {
 				function main () {
 				
 					var element = window.parent.document.forms ['$_REQUEST{__only_form}'].elements ['_$_REQUEST{__only_field}'];
+					var html = "$page->{body}";
 					
 					if (element) {
-						element.outerHTML = "$page->{body}";
+						element.outerHTML = html;
 						element.tabIndex = "$_REQUEST{__only_tabindex}";
 					}
 					else {
 						element = window.parent.document.getElementById ('input_$_REQUEST{__only_field}');
-						element.outerHTML = "$page->{body}";
+						element.outerHTML = html;
 					}
 					
 				}
@@ -2172,6 +2173,9 @@ EOF
           }
 
 					
+				
+					$_REQUEST{__script}
+				
 				</script>
 				
 				@{[ $_REQUEST{__help_url} ? <<EOHELP : '' ]}
